==> libphp-phpmailer_5.2.9+dfsg.orig.tar.gz: PHPMailer-5.2.9/language/phpmailer.lang-se.php <==
<?php
/**
 * Swedish PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Johan Linnér <johan@linner.biz>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP fel: Kunde inte autentisera.';
$PHPMAILER_LANG['connect_host']         = 'SMTP fel: Kunde inte ansluta till SMTP-server.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP fel: Data accepterades inte.';
//$PHPMAILER_LANG['empty_message']        = 'Message body empty';
$PHPMAILER_LANG['encoding']             = 'Okänt encode-format: ';
$PHPMAILER_LANG['execute']              = 'Kunde inte köra: ';
$PHPMAILER_LANG['file_access']          = 'Ingen åtkomst till fil: ';
$PHPMAILER_LANG['file_open']            = 'Fil fel: Kunde inte öppna fil: ';
$PHPMAILER_LANG['from_failed']          = 'Följande avsändaradress är felaktig: ';
$PHPMAILER_LANG['instantiate']          = 'Kunde inte initiera e-postfunktion.';
//$PHPMAILER_LANG['invalid_address']        = 'Not sending, email address is invalid: ';
$PHPMAILER_LANG['provide_address']      = 'Du måste ange minst en mottagares e-postadress.';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer stöds inte.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP fel: Följande mottagare är felaktig: ';
//$PHPMAILER_LANG['signing']              = 'Signing Error: ';
//$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() failed.';
//$PHPMAILER_LANG['smtp_error']           = 'SMTP server error: ';
//$PHPMAILER_LANG['variable_set']         = 'Cannot set or reset variable: ';

==> libphp-phpmailer_5.2.14+dfsg.orig.tar.gz: PHPMailer-5.2.14/language/phpmailer.lang-se.php <==
<?php
/**
 * Swedish PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Johan Linnér <johan@linner.biz>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP fel: Kunde inte autentisera.';
$PHPMAILER_LANG['connect_host']         = 'SMTP fel: Kunde inte ansluta till SMTP-server.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP fel: Data accepterades inte.';
//$PHPMAILER_LANG['empty_message']        = 'Message body empty';
$PHPMAILER_LANG['encoding']             = 'Okänt encode-format: ';
$PHPMAILER_LANG['execute']              = 'Kunde inte köra: ';
$PHPMAILER_LANG['file_access']          = 'Ingen åtkomst till fil: ';
$PHPMAILER_LANG['file_open']            = 'Fil fel: Kunde inte öppna fil: ';
$PHPMAILER_LANG['from_failed']          = 'Följande avsändaradress är felaktig: ';
$PHPMAILER_LANG['instantiate']          = 'Kunde inte initiera e-postfunktion.';
//$PHPMAILER_LANG['invalid_address']      = 'Invalid address: ';
$PHPMAILER_LANG['provide_address']      = 'Du måste ange minst en mottagares e-postadress.';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer stöds inte.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP fel: Följande mottagare är felaktig: ';
//$PHPMAILER_LANG['signing']              = 'Signing Error: ';
//$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() failed.';
//$PHPMAILER_LANG['smtp_error']           = 'SMTP server error: ';
//$PHPMAILER_LANG['variable_set']         = 'Cannot set or reset variable: ';
//$PHPMAILER_LANG['extension_missing']    = 'Extension missing: ';
